
/*  CreateVTCfiles_BV23.js
    Script to create VTC files 
    By Rainer Goebel 2005
    Modified for QX 2.1 by HB 2009, for BV21 by HB 030419, 060619, for BV23 090224
*/

/* This information is used in the functions */
//    Setting hardcoded paths:
/*    var ObjectsRawDataPath = "/Users/BVuser/Data/ObjectsDicomGSG/";
    var nameFMR = ObjectsRawDataPath + "CG_OBJECTS_SCRIPT_SCLAI_3DMCTS_SD3DSS4.00mm_LTR_THP3c_TDTS10.0s.fmr";
    var nameVMRinNative = ObjectsRawDataPath +"CG_3DT1MPR_SCRIPT.vmr";
    ...
    var nameVTCinTAL= ObjectsRawDataPath + "CG_OBJECTS_SCRIPT_TAL.vtc";
    etc...
 */

    // Setting paths via file selection dialog:
    var nameVMR         = BrainVoyager.BrowseFile("Please select the VMR file", "*.vmr");
    var nameFMR         = BrainVoyager.BrowseFile("Please select the FMR file", "*.fmr");
    var nameIAfile      = BrainVoyager.BrowseFile("Please select the initial alignment file", "*IA.trf");
    var nameFAfile      = BrainVoyager.BrowseFile("Please select the fine alignment file", "*FA.trf");
//   var nameACPCfile   = BrainVoyager.BrowseFile("Please select the AC-PC transformation file", "*ACPC.trf");
//   var nameTALfile    = BrainVoyager.BrowseFile("Please select the Talairach landmarks file", "*.tal");
    var nameMNIfile     = BrainVoyager.BrowseFile("Please select the MNI transformation file", "*.trf"); //"MNI_a12_adjBBX.trf"

    var dataType = 2; // 1: int16, 2: float32
    var resolution = 2; // one of 1, 2 or 3 mm^2
    var interpolation = 1; // ‘0’ for nearest neighbor interpolation, ‘1’ for trilinear interpolation, ‘2’ for sinc interpolation
    var threshold = 100; // intensity threshold for bounding box (is not relevant for Talairach space, but should be provided). Default value in GUI: ‘100’.
    var extendedBoundingBox = false;

    BrainVoyager.ShowLogPane();
    BrainVoyager.PrintToLog("Start creating VTCs...");
     
    try {
    //  CreateVTCinNativeSpace(); 
    //  CreateVTCinAcpcSpace();
    //  CreateVTCinTalairachSpace(false); // make a VTC in Talairach space with extended bounding box = false
    //  CreateVTCinTalairachSpace(true); // make a VTC in Talairach space with extended bounding box (in z-dir)
        CreateVTCinMNISpace(); 
    } catch (e) {
        BrainVoyager.PrintToLog("Error: " + e);
    }

/* These functions are invoked from the section above */
    function CreateVTCinNativeSpace() 
    {
        var docVMR = BrainVoyager.OpenDocument(nameVMR);
        docVMR.ExtendedTALSpaceForVTCCreation = false; 
        var nameVTCinNative = getNewName(nameFMR, "_NATIVE", ".vtc");
        var success = docVMR.CreateVTCInVMRSpace(nameFMR, nameIAfile, nameFAfile, nameVTCinNative, dataType, resolution, interpolation, threshold);
        if (success) BrainVoyager.PrintToLog("Created VTC file: " + nameVTCinNative);
        docVMR.Close();
    }

    function CreateVTCinAcpcSpace() 
    {
        var docVMR = BrainVoyager.OpenDocument(nameVMR);
        var nameVTCinACPC = getNewName(nameFMR, "_ACPC", ".vtc");
        docVMR.ExtendedTALSpaceForVTCCreation = false;
        var success = docVMR.CreateVTCInACPCSpace(nameFMR, nameIAfile, nameFAfile, nameACPCfile, nameVTCinACPC, dataType, resolution, interpolation, threshold);
        docVMR.Close();
    }

    function CreateVTCinTalairachSpace(useExtendedBoundingBox) 
    {
        var docVMR = BrainVoyager.OpenDocument(nameVMR);
        var nameVTCinTAL = getNewName(nameFMR, "_TAL", ".vtc");
        docVMR.ExtendedTALSpaceForVTCCreation = useExtendedBoundingBox; // this is true or false
        var success = docVMR.CreateVTCInTALSpace(nameFMR, nameIAfile, nameFAfile, nameACPCfile, nameTALfile, 
                                                    nameVTCinTAL, dataType, resolution, interpolation, threshold);
        docVMR.Close();
    }

    function CreateVTCinMNISpace() 
    {
        var docVMR = BrainVoyager.OpenDocument(nameVMR);
        var nameVTCinMNI = getNewName(nameFMR, "_MNI", ".vtc");
        docVMR.ExtendedTALSpaceForVTCCreation = false;
        var success = docVMR.CreateVTCInMNISpace(nameFMR, nameIAfile, nameFAfile, nameMNIfile,  
                                                    nameVTCinMNI, dataType, resolution, interpolation, threshold);
        docVMR.Close();
    }

    function getNewName(name, infix, suffix) {
        var pos = name.lastIndexOf(".");
        var newname = name.substring(0, pos) + infix + suffix;
        BrainVoyager.PrintToLog("New name: " + newname);        
        return newname;
    }

